/*
 * file CqReportFormat.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cq.CqReportFormat
 *
 * (C) Copyright IBM Corporation 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cq;

import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

import com.ibm.rational.wvcm.stpex.StpExBase;

/**
 * An interface specification for the proxy for a ClearQuest report format
 * resource. New report formats cannot be created via this API. The Crystal
 * Reports definition file can be obtained through this API by invoking
 * doReadContent on a CqReportFormat proxy.
 * <p>
 * The user-friendly specification for the location of a report format has the
 * form
 * 
 * <pre>
 *  <b>cq.query:</b><i>&lt;parent-folder-path&gt;</i>/<i>&lt;report-format-name&gt;</i>@<i>&lt;db-set&gt;</i>/<i>&lt;user-db&gt;</i>
 * </pre>
 */
public interface CqReportFormat extends CqQueryFolderItem
{
    /**
     * The type of record for which this report format is defined.
     */
    PropertyName<CqRecordType> RECORD_TYPE =
        new PropertyName<CqRecordType>(StpExBase.PROPERTY_NAMESPACE,
                                       "record-type");

    /**
     * Returns the value of the {@link #RECORD_TYPE RECORD_TYPE} property as
     * defined by this proxy.
     * 
     * @return A CqRecordType proxy specifying the type of record this report
     *         format is designed to format.
     * 
     * @throws WvcmException if this proxy does not define a value for the
     *             {@link #RECORD_TYPE RECORD_TYPE} property.
     */
    CqRecordType getRecordType() throws WvcmException;
}
